searchData={"items":[{"type":"behaviour","title":"Quantum","doc":"Defines a quantum Scheduler.\n\nWhen used, the quantum scheduler expects the `:otp_app` as option.\nThe `:otp_app` should point to an OTP application that has\nthe quantum runner configuration. For example, the quantum scheduler:\n\n    defmodule MyApp.Scheduler do\n      use Quantum, otp_app: :my_app\n    end\n\nCould be configured with:\n\n    config :my_app, MyApp.Scheduler,\n      jobs: [\n        {\"@daily\", {Backup, :backup, []}},\n      ]","ref":"Quantum.html"},{"type":"behaviour","title":"Configuration: - Quantum","doc":"* `:clock_broadcaster_name` - GenServer name of clock broadcaster \\\n    *(unstable, may break without major release until declared stable)*\n\n  * `:execution_broadcaster_name` - GenServer name of execution broadcaster \\\n    *(unstable, may break without major release until declared stable)*\n\n  * `:executor_supervisor_name` - GenServer name of execution supervisor \\\n    *(unstable, may break without major release until declared stable)*\n\n  * `:debug_logging` - Turn on debug logging\n\n  * `:jobs` - list of cron jobs to execute\n\n  * `:job_broadcaster_name` - GenServer name of job broadcaster \\\n    *(unstable, may break without major release until declared stable)*\n\n  * `:name` - GenServer name of scheduler \\\n    *(unstable, may break without major release until declared stable)*\n\n  * `:node_selector_broadcaster_name` - GenServer name of node selector broadcaster \\\n    *(unstable, may break without major release until declared stable)*\n\n  * `:overlap` - Default overlap of new Job\n\n  * `:otp_app` - Application where scheduler runs\n\n  * `:run_strategy` - Default Run Strategy of new Job\n\n  * `:schedule` - Default schedule of new Job\n\n  * `:storage` - Storage to use for persistence\n\n  * `:storage_name` - GenServer name of storage \\\n    *(unstable, may break without major release until declared stable)*\n\n  * `:supervisor_module` - Module to supervise scheduler \\\n    Can be overwritten to supervise processes differently (for example for clustering) \\\n    *(unstable, may break without major release until declared stable)*\n\n  * `:task_registry_name` - GenServer name of task registry \\\n    *(unstable, may break without major release until declared stable)*\n\n  * `:task_supervisor_name` - GenServer name of task supervisor \\\n    *(unstable, may break without major release until declared stable)*\n\n  * `:timeout` - Sometimes, you may come across GenServer timeout errors\n    esp. when you have too many jobs or high load. The default `GenServer.call/3`\n    timeout is `5_000`.\n\n  * `:timezone` - Default timezone of new Job","ref":"Quantum.html#module-configuration"},{"type":"behaviour","title":"Telemetry - Quantum","doc":"* `[:quantum, :job, :add]`\n  * Description: dispatched when a job is added\n  * Measurements: `%{}`\n  * Metadata: `%{job: Quantum.Job.t(), scheduler: atom()}`\n\n* `[:quantum, :job, :update]`\n  * Description: dispatched when a job is updated\n  * Measurements: `%{}`\n  * Metadata: `%{job: Quantum.Job.t(), scheduler: atom()}`\n\n* `[:quantum, :job, :delete]`\n  * Description: dispatched when a job is deleted\n  * Measurements: `%{}`\n  * Metadata: `%{job: Quantum.Job.t(), scheduler: atom()}`\n\n* `[:quantum, :job, :start]`\n  * Description: dispatched on job execution start\n  * Measurements: `%{system_time: integer()}`\n  * Metadata: `%{telemetry_span_context: term(), job: Quantum.Job.t(), node: Node.t(), scheduler: atom()}`\n\n* `[:quantum, :job, :stop]`\n  * Description: dispatched on job execution end\n  * Measurements: `%{duration: integer()}`\n  * Metadata: `%{telemetry_span_context: term(), job: Quantum.Job.t(), node: Node.t(), scheduler: atom(), result: term()}`\n\n* `[:quantum, :job, :exception]`\n  * Description: dispatched on job execution fail\n  * Measurements: `%{duration: integer()}`\n  * Metadata: `%{telemetry_span_context: term(), job: Quantum.Job.t(), node: Node.t(), scheduler: atom(), kind: :throw | :error | :exit, reason: term(), stacktrace: list()}`\n\n\n\n#","ref":"Quantum.html#module-telemetry"},{"type":"behaviour","title":"Examples - Quantum","doc":"iex(1)> :telemetry_registry.discover_all(:quantum)\n    :ok\n    iex(2)> :telemetry_registry.spannable_events()\n    [{[:quantum, :job], [:start, :stop, :exception]}]\n    iex(3)> :telemetry_registry.list_events\n    [\n      {[:quantum, :job, :add], Quantum,\n       %{\n         description: \"dispatched when a job is added\",\n         measurements: \"%{}\",\n         metadata: \"%{job: Quantum.Job.t(), scheduler: atom()}\"\n       }},\n      {[:quantum, :job, :delete], Quantum,\n       %{\n         description: \"dispatched when a job is deleted\",\n         measurements: \"%{}\",\n         metadata: \"%{job: Quantum.Job.t(), scheduler: atom()}\"\n       }},\n      {[:quantum, :job, :exception], Quantum,\n       %{\n         description: \"dispatched on job execution fail\",\n         measurements: \"%{duration: integer()}\",\n         metadata: \"%{telemetry_span_context: term(), job: Quantum.Job.t(), node: Node.t(), scheduler: atom(), kind: :throw | :error | :exit, reason: term(), stacktrace: list()}\"\n       }},\n      {[:quantum, :job, :start], Quantum,\n       %{\n         description: \"dispatched on job execution start\",\n         measurements: \"%{system_time: integer()}\",\n         metadata: \"%{telemetry_span_context: term(), job: Quantum.Job.t(), node: Node.t(), scheduler: atom()}\"\n       }},\n      {[:quantum, :job, :stop], Quantum,\n       %{\n         description: \"dispatched on job execution end\",\n         measurements: \"%{duration: integer()}\",\n         metadata: \"%{telemetry_span_context: term(), job: Quantum.Job.t(), node: Node.t(), scheduler: atom(), result: term()}\"\n       }},\n      {[:quantum, :job, :update], Quantum,\n       %{\n         description: \"dispatched when a job is updated\",\n         measurements: \"%{}\",\n         metadata: \"%{job: Quantum.Job.t(), scheduler: atom()}\"\n       }}\n    ]","ref":"Quantum.html#module-examples"},{"type":"callback","title":"Quantum.activate_job/2","doc":"Activates a job by name","ref":"Quantum.html#c:activate_job/2"},{"type":"callback","title":"Quantum.add_job/2","doc":"Adds a new job","ref":"Quantum.html#c:add_job/2"},{"type":"callback","title":"Quantum.config/1","doc":"","ref":"Quantum.html#c:config/1"},{"type":"callback","title":"Quantum.deactivate_job/2","doc":"Deactivates a job by name","ref":"Quantum.html#c:deactivate_job/2"},{"type":"callback","title":"Quantum.delete_all_jobs/1","doc":"Deletes all jobs","ref":"Quantum.html#c:delete_all_jobs/1"},{"type":"callback","title":"Quantum.delete_job/2","doc":"Deletes a job by name","ref":"Quantum.html#c:delete_job/2"},{"type":"callback","title":"Quantum.find_job/2","doc":"Resolves a job by name","ref":"Quantum.html#c:find_job/2"},{"type":"callback","title":"Quantum.init/1","doc":"A callback executed when the quantum starts.\n\nIt takes the quantum configuration that is stored in the application\nenvironment, and may change it to suit the application business.\n\nIt must return the updated list of configuration","ref":"Quantum.html#c:init/1"},{"type":"callback","title":"Quantum.jobs/1","doc":"Returns the list of currently defined jobs","ref":"Quantum.html#c:jobs/1"},{"type":"callback","title":"Quantum.new_job/1","doc":"Creates a new Job. The job can be added by calling `add_job/1`.","ref":"Quantum.html#c:new_job/1"},{"type":"callback","title":"Supported options - Quantum.new_job/1","doc":"* `name` - see `Quantum.Job.set_name/2`\n* `overlap` - see `Quantum.Job.set_overlap/2`\n* `run_strategy` - see `Quantum.Job.set_run_strategy/2`\n* `schedule` - see `Quantum.Job.set_schedule/2`\n* `state` - see `Quantum.Job.set_state/2`\n* `task` - see `Quantum.Job.set_task/2`\n* `timezone` - see `Quantum.Job.set_timezone/2`","ref":"Quantum.html#c:new_job/1-supported-options"},{"type":"callback","title":"Quantum.run_job/2","doc":"Runs a job by name once","ref":"Quantum.html#c:run_job/2"},{"type":"callback","title":"Quantum.start_link/1","doc":"Starts supervision and return `{:ok, pid}`\nor just `:ok` if nothing needs to be done.\n\nReturns `{:error, {:already_started, pid}}` if the scheduler is already\nstarted or `{:error, term}` in case anything else goes wrong.","ref":"Quantum.html#c:start_link/1"},{"type":"callback","title":"Options - Quantum.start_link/1","doc":"See the configuration in the moduledoc for options.","ref":"Quantum.html#c:start_link/1-options"},{"type":"callback","title":"Quantum.stop/2","doc":"Shuts down the quantum represented by the given pid.","ref":"Quantum.html#c:stop/2"},{"type":"type","title":"Quantum.t/0","doc":"Quantum Scheduler Implementation","ref":"Quantum.html#t:t/0"},{"type":"module","title":"Quantum.Job","doc":"This Struct defines a Job.","ref":"Quantum.Job.html"},{"type":"module","title":"Usage - Quantum.Job","doc":"The struct should never be defined by hand. Use `c:Quantum.new_job/1` to create a new job and use the setters mentioned\nbelow to mutate the job.\n\nThis is to ensure type safety.","ref":"Quantum.Job.html#module-usage"},{"type":"function","title":"Quantum.Job.set_name/2","doc":"Sets a job's name.\n\n#","ref":"Quantum.Job.html#set_name/2"},{"type":"function","title":"Parameters - Quantum.Job.set_name/2","doc":"1. `job` - The job struct to modify\n  2. `name` - The name to set\n\n#","ref":"Quantum.Job.html#set_name/2-parameters"},{"type":"function","title":"Examples - Quantum.Job.set_name/2","doc":"iex> Acme.Scheduler.new_job()\n    ...> |> Quantum.Job.set_name(:name)\n    ...> |> Map.get(:name)\n    :name","ref":"Quantum.Job.html#set_name/2-examples"},{"type":"function","title":"Quantum.Job.set_overlap/2","doc":"Sets a job's overlap.\n\n#","ref":"Quantum.Job.html#set_overlap/2"},{"type":"function","title":"Parameters - Quantum.Job.set_overlap/2","doc":"1. `job` - The job struct to modify\n  2. `overlap` - Enable / Disable Overlap\n\n#","ref":"Quantum.Job.html#set_overlap/2-parameters"},{"type":"function","title":"Examples - Quantum.Job.set_overlap/2","doc":"iex> Acme.Scheduler.new_job()\n    ...> |> Quantum.Job.set_overlap(false)\n    ...> |> Map.get(:overlap)\n    false","ref":"Quantum.Job.html#set_overlap/2-examples"},{"type":"function","title":"Quantum.Job.set_run_strategy/2","doc":"Sets a job's run strategy.\n\n#","ref":"Quantum.Job.html#set_run_strategy/2"},{"type":"function","title":"Parameters - Quantum.Job.set_run_strategy/2","doc":"1. `job` - The job struct to modify\n  2. `run_strategy` - The run strategy to set\n\n#","ref":"Quantum.Job.html#set_run_strategy/2-parameters"},{"type":"function","title":"Examples - Quantum.Job.set_run_strategy/2","doc":"iex> Acme.Scheduler.new_job()\n    ...> |> Quantum.Job.run_strategy(%Quantum.RunStrategy.All{nodes: [:one, :two]})\n    ...> |> Map.get(:run_strategy)\n    [:one, :two]","ref":"Quantum.Job.html#set_run_strategy/2-examples"},{"type":"function","title":"Quantum.Job.set_schedule/2","doc":"Sets a job's schedule.\n\n#","ref":"Quantum.Job.html#set_schedule/2"},{"type":"function","title":"Parameters - Quantum.Job.set_schedule/2","doc":"1. `job` - The job struct to modify\n  2. `schedule` - The schedule to set. May only be of type `%Crontab.CronExpression{}`\n\n#","ref":"Quantum.Job.html#set_schedule/2-parameters"},{"type":"function","title":"Examples - Quantum.Job.set_schedule/2","doc":"iex> Acme.Scheduler.new_job()\n    ...> |> Quantum.Job.set_schedule(Crontab.CronExpression.Parser.parse!(\"*/7\"))\n    ...> |> Map.get(:schedule)\n    Crontab.CronExpression.Parser.parse!(\"*/7\")","ref":"Quantum.Job.html#set_schedule/2-examples"},{"type":"function","title":"Quantum.Job.set_state/2","doc":"Sets a job's state.\n\n#","ref":"Quantum.Job.html#set_state/2"},{"type":"function","title":"Parameters - Quantum.Job.set_state/2","doc":"1. `job` - The job struct to modify\n  2. `state` - The state to set\n\n#","ref":"Quantum.Job.html#set_state/2-parameters"},{"type":"function","title":"Examples - Quantum.Job.set_state/2","doc":"iex> Acme.Scheduler.new_job()\n    ...> |> Quantum.Job.set_state(:active)\n    ...> |> Map.get(:state)\n    :active","ref":"Quantum.Job.html#set_state/2-examples"},{"type":"function","title":"Quantum.Job.set_task/2","doc":"Sets a job's task.\n\n#","ref":"Quantum.Job.html#set_task/2"},{"type":"function","title":"Parameters - Quantum.Job.set_task/2","doc":"1. `job` - The job struct to modify\n  2. `task` - The function to be performed, ex: `{Heartbeat, :send, []}` or `fn -> :something end`\n\n#","ref":"Quantum.Job.html#set_task/2-parameters"},{"type":"function","title":"Examples - Quantum.Job.set_task/2","doc":"iex> Acme.Scheduler.new_job()\n    ...> |> Quantum.Job.set_task({Backup, :backup, []})\n    ...> |> Map.get(:task)\n    {Backup, :backup, []}","ref":"Quantum.Job.html#set_task/2-examples"},{"type":"function","title":"Quantum.Job.set_timezone/2","doc":"Sets a job's timezone.\n\n#","ref":"Quantum.Job.html#set_timezone/2"},{"type":"function","title":"Parameters - Quantum.Job.set_timezone/2","doc":"1. `job` - The job struct to modify\n  2. `timezone` - The timezone to set.\n\n#","ref":"Quantum.Job.html#set_timezone/2-parameters"},{"type":"function","title":"Examples - Quantum.Job.set_timezone/2","doc":"iex> Acme.Scheduler.new_job()\n    ...> |> Quantum.Job.set_timezone(\"Europe/Zurich\")\n    ...> |> Map.get(:timezone)\n    \"Europe/Zurich\"","ref":"Quantum.Job.html#set_timezone/2-examples"},{"type":"type","title":"Quantum.Job.name/0","doc":"","ref":"Quantum.Job.html#t:name/0"},{"type":"type","title":"Quantum.Job.schedule/0","doc":"","ref":"Quantum.Job.html#t:schedule/0"},{"type":"type","title":"Quantum.Job.state/0","doc":"","ref":"Quantum.Job.html#t:state/0"},{"type":"type","title":"Quantum.Job.t/0","doc":"","ref":"Quantum.Job.html#t:t/0"},{"type":"type","title":"Quantum.Job.task/0","doc":"","ref":"Quantum.Job.html#t:task/0"},{"type":"type","title":"Quantum.Job.timezone/0","doc":"","ref":"Quantum.Job.html#t:timezone/0"},{"type":"behaviour","title":"Quantum.RunStrategy","doc":"Config Normalizer of a `Quantum.RunStrategy.NodeList`.","ref":"Quantum.RunStrategy.html"},{"type":"callback","title":"Quantum.RunStrategy.normalize_config!/1","doc":"Normalize given config to a value that has `Quantum.RunStrategy.NodeList` implemented.\n\nRaise / Do not Match on invalid config.","ref":"Quantum.RunStrategy.html#c:normalize_config!/1"},{"type":"module","title":"Quantum.RunStrategy.All","doc":"Run job on all node of the node list.\n\nIf the node list is `:cluster`, all nodes of the cluster will be used.\n\n#","ref":"Quantum.RunStrategy.All.html"},{"type":"module","title":"Mix Configuration - Quantum.RunStrategy.All","doc":"config :my_app, MyApp.Scheduler,\n      jobs: [\n        # Run on all nodes in cluster\n        [schedule: \"* * * * *\", run_strategy: {Quantum.RunStrategy.All, :cluster}],\n        # Run on all nodes of given list\n        [schedule: \"* * * * *\", run_strategy: {Quantum.RunStrategy.All, [:\"node@host1\", :\"node@host2\"]}],\n      ]","ref":"Quantum.RunStrategy.All.html#module-mix-configuration"},{"type":"module","title":"Quantum.RunStrategy.Local","doc":"Run job on local node\n\n#","ref":"Quantum.RunStrategy.Local.html"},{"type":"module","title":"Mix Configuration - Quantum.RunStrategy.Local","doc":"config :my_app, MyApp.Scheduler,\n      jobs: [\n        # Run on local node\n        [schedule: \"* * * * *\", run_strategy: Quantum.RunStrategy.Local]\n      ]","ref":"Quantum.RunStrategy.Local.html#module-mix-configuration"},{"type":"protocol","title":"Quantum.RunStrategy.NodeList","doc":"Strategy to run Jobs over nodes","ref":"Quantum.RunStrategy.NodeList.html"},{"type":"function","title":"Quantum.RunStrategy.NodeList.nodes/2","doc":"Get nodes to run on","ref":"Quantum.RunStrategy.NodeList.html#nodes/2"},{"type":"type","title":"Quantum.RunStrategy.NodeList.t/0","doc":"All the types that implement this protocol.","ref":"Quantum.RunStrategy.NodeList.html#t:t/0"},{"type":"module","title":"Quantum.RunStrategy.Random","doc":"Run job on one node of the list randomly.\n\nIf the node list is `:cluster`, one node of the cluster will be used.\n\nThis run strategy also makes sure, that the node doesn't run in two places at the same time\nif `job.overlap` is falsy.\n\n#","ref":"Quantum.RunStrategy.Random.html"},{"type":"module","title":"Mix Configuration - Quantum.RunStrategy.Random","doc":"config :my_app, MyApp.Scheduler,\n      jobs: [\n        # Run on any node in cluster\n        [schedule: \"* * * * *\", run_strategy: {Quantum.RunStrategy.Random, :cluster}],\n        # Run on any node of given list\n        [schedule: \"* * * * *\", run_strategy: {Quantum.RunStrategy.Random, [:\"node@host1\", :\"node@host2\"]}],\n      ]","ref":"Quantum.RunStrategy.Random.html#module-mix-configuration"},{"type":"behaviour","title":"Quantum.Storage","doc":"Behaviour to be implemented by all Storage Adapters.\n\nThe calls to the storage are blocking, make sure they're fast to not block the job execution.","ref":"Quantum.Storage.html"},{"type":"callback","title":"Quantum.Storage.add_job/2","doc":"Save new job in storage.","ref":"Quantum.Storage.html#c:add_job/2"},{"type":"callback","title":"Quantum.Storage.child_spec/1","doc":"Storage child spec\n\nIf the storage does not need a process, specify a function that returns `:ignore`.\n\n#","ref":"Quantum.Storage.html#c:child_spec/1"},{"type":"callback","title":"Values - Quantum.Storage.child_spec/1","doc":"* `:scheduler` - The Scheduler","ref":"Quantum.Storage.html#c:child_spec/1-values"},{"type":"callback","title":"Quantum.Storage.delete_job/2","doc":"Delete new job in storage.","ref":"Quantum.Storage.html#c:delete_job/2"},{"type":"callback","title":"Quantum.Storage.jobs/1","doc":"Load saved jobs from storage.\n\nReturns `:not_applicable` if the storage has never received an `add_job` call or after it has been purged.\nIn this case the jobs from the configuration will be loaded.","ref":"Quantum.Storage.html#c:jobs/1"},{"type":"callback","title":"Quantum.Storage.last_execution_date/1","doc":"Load last execution time from storage.\n\nReturns `:unknown` if the storage does not know the last execution time.\nIn this case all jobs will be run at the next applicable date.","ref":"Quantum.Storage.html#c:last_execution_date/1"},{"type":"callback","title":"Quantum.Storage.purge/1","doc":"Purge all date from storage and go back to initial state.","ref":"Quantum.Storage.html#c:purge/1"},{"type":"callback","title":"Quantum.Storage.update_job/2","doc":"Updates existing job in storage.\n\nThis callback is optional. If not implemented then the `c:delete_job/2`\nand then the `c:add_job/2` callbacks will be called instead.","ref":"Quantum.Storage.html#c:update_job/2"},{"type":"callback","title":"Quantum.Storage.update_job_state/3","doc":"Change Job State from given job.","ref":"Quantum.Storage.html#c:update_job_state/3"},{"type":"callback","title":"Quantum.Storage.update_last_execution_date/2","doc":"Update last execution time to given date.","ref":"Quantum.Storage.html#c:update_last_execution_date/2"},{"type":"type","title":"Quantum.Storage.storage_pid/0","doc":"The location of the `server`.\n\n#","ref":"Quantum.Storage.html#t:storage_pid/0"},{"type":"type","title":"Values - Quantum.Storage.storage_pid/0","doc":"* `nil` if the storage was not started\n* `server()` if the storage was started","ref":"Quantum.Storage.html#t:storage_pid/0-values"},{"type":"module","title":"Quantum.Storage.Noop","doc":"Empty implementation of a `Quantum.Storage`.","ref":"Quantum.Storage.Noop.html"},{"type":"function","title":"Quantum.Storage.Noop.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Quantum.Storage.Noop.html#child_spec/1"},{"type":"extras","title":"Change Log","doc":"# Change Log\nAll notable changes to this project will be documented in this file.\nThis project adheres to [Semantic Versioning](http://semver.org/).","ref":"changelog.html"},{"type":"extras","title":"Unreleased - Change Log","doc":"Diff for [unreleased]","ref":"changelog.html#unreleased"},{"type":"extras","title":"3.4.0 - 2021-08-10 - Change Log","doc":"#","ref":"changelog.html#3-4-0-2021-08-10"},{"type":"extras","title":"Added - Change Log","doc":"- `telemetry` `v1.0.0` support (#483)\n- Logger Metadata (#462 & #464)\n- Support setting job `state` in config (#463)\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Change Log","doc":"- Invalid Timezone fix in `ExecutionBroadcaster` (#468)\n\nDiff for [3.4.0]","ref":"changelog.html#fixed"},{"type":"extras","title":"3.3.0 - 2020-09-25 - Change Log","doc":"#","ref":"changelog.html#3-3-0-2020-09-25"},{"type":"extras","title":"Added - Change Log","doc":"- Support manual job triggering (#459)\n\nDiff for [3.3.0]","ref":"changelog.html#added"},{"type":"extras","title":"3.2.0 - 2020-09-14 - Change Log","doc":"#","ref":"changelog.html#3-2-0-2020-09-14"},{"type":"extras","title":"Added - Change Log","doc":"- Telemetry Support (#415)\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Change Log","doc":"- Properly override jobs with duplicate name (#392)\n- Simplify `TaskRegistry` and make tests deterministic\n\nDiff for [3.2.0]","ref":"changelog.html#fixed"},{"type":"extras","title":"3.1.0 - 2020-08-18 - Change Log","doc":"#","ref":"changelog.html#3-1-0-2020-08-18"},{"type":"extras","title":"Added - Change Log","doc":"- Additional Supervisor Configuration for Clustering (#450)\n\nDiff for [3.1.0]","ref":"changelog.html#added"},{"type":"extras","title":"3.0.2 - 2020-08-18 - Change Log","doc":"#","ref":"changelog.html#3-0-2-2020-08-18"},{"type":"extras","title":"Fixed - Change Log","doc":"- Fix Warnings with Clock Skew (#449)\n\nDiff for [3.0.2]","ref":"changelog.html#fixed"},{"type":"extras","title":"3.0.1 - 2020-06-16 - Change Log","doc":"#","ref":"changelog.html#3-0-1-2020-06-16"},{"type":"extras","title":"Fixed - Change Log","doc":"- `ClockEvent` order corrected\n\nDiff for [3.0.1]","ref":"changelog.html#fixed"},{"type":"extras","title":"3.0.0 - 2020-06-11 - Change Log","doc":"#","ref":"changelog.html#3-0-0-2020-06-11"},{"type":"extras","title":"Fixed - Change Log","doc":"- Fix `@reboot` Cron Expression (#437)\n\nDiff for [3.0.0]","ref":"changelog.html#fixed"},{"type":"extras","title":"3.0.0-rc.3 - 2020-02-28 - Change Log","doc":"#","ref":"changelog.html#3-0-0-rc-3-2020-02-28"},{"type":"extras","title":"Fixed - Change Log","doc":"- Update Docs\n\nDiff for [3.0.0-rc.3]","ref":"changelog.html#fixed"},{"type":"extras","title":"3.0.0-rc.2 - 2020-02-28 - Change Log","doc":"#","ref":"changelog.html#3-0-0-rc-2-2020-02-28"},{"type":"extras","title":"Changed - Change Log","doc":"- The `Quantum.Storage` behaviour contains a new  mandatory `child_spec/1` callback.\n\nDiff for [3.0.0-rc.2]","ref":"changelog.html#changed"},{"type":"extras","title":"3.0.0-rc.1 - 2020-02-26 - Change Log","doc":"#","ref":"changelog.html#3-0-0-rc-1-2020-02-26"},{"type":"extras","title":"Changed - Change Log","doc":"- A lot of function that were not for public use have been undocumented. Those are now considered internal and may break at any point in time.\n- `Quantum.Scheduler` has been renamed to `Quantum`\n- `Quantum.Storage.Adapter` has been renamed to `Quantum.Storage`\n- The `global` mode has been removed. It will be reimplemented if a stable replacement is found.\n\nDiff for [3.0.0-rc.1]","ref":"changelog.html#changed"},{"type":"extras","title":"2.4.0 - 2020-02-25 - Change Log","doc":"#","ref":"changelog.html#2-4-0-2020-02-25"},{"type":"extras","title":"Added - Change Log","doc":"- Native Date Library (via #405)\n- Adding of inactive Jobs (via #409)\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Change Log","doc":"- GenStage 1.0 compatibility (via #424)\n- Doc Fixes (#394, #396, #400, #401)\n\nDiff for [2.4.0]","ref":"changelog.html#fixed"},{"type":"extras","title":"2.3.4 - 2019-01-06 - Change Log","doc":"#","ref":"changelog.html#2-3-4-2019-01-06"},{"type":"extras","title":"Fixed - Change Log","doc":"- Faster Startup duration for non-global (Fixes #376)\n\nDiff for [2.3.4]","ref":"changelog.html#fixed"},{"type":"extras","title":"2.3.3 - 2018-09-06 - Change Log","doc":"#","ref":"changelog.html#2-3-3-2018-09-06"},{"type":"extras","title":"Fixed - Change Log","doc":"- Fix & Test Swarm Handoff & Conflict Resolution\n- Fix Compilation Error\n- Fix Executor Stat Options for GenStage ~> 0.12.0\n\nDiff for [2.3.3]","ref":"changelog.html#fixed"},{"type":"extras","title":"2.3.2 - 2018-08-21 - Change Log","doc":"#","ref":"changelog.html#2-3-2-2018-08-21"},{"type":"extras","title":"Fixed - Change Log","doc":"- Global Clustering Worker Start\n\nDiff for [2.3.2]","ref":"changelog.html#fixed"},{"type":"extras","title":"2.3.1 - 2018-08-13 - Change Log","doc":"#","ref":"changelog.html#2-3-1-2018-08-13"},{"type":"extras","title":"Fixed - Change Log","doc":"- Fixed Regression in Run Strategy Random\n\nDiff for [2.3.1]","ref":"changelog.html#fixed"},{"type":"extras","title":"2.3.0 - 2018-08-10 - Change Log","doc":"#","ref":"changelog.html#2-3-0-2018-08-10"},{"type":"extras","title":"Added - Change Log","doc":"- Experimental Storage API\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Change Log","doc":"- Use Swarm for clustering to prevent broken cluster state\n- Better search for available nodes for run strategies\n\nDiff for [2.3.0]","ref":"changelog.html#fixed"},{"type":"extras","title":"2.2.7 - 2018-03-22 - Change Log","doc":"#","ref":"changelog.html#2-2-7-2018-03-22"},{"type":"extras","title":"Changed - Change Log","doc":"- Moved the Repository into Organization & Correct all the URL's\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Change Log","doc":"- Fixed Dialyzer Warnings\n\nDiff for [2.2.7]","ref":"changelog.html#fixed"},{"type":"extras","title":"2.2.6 - 2018-03-21 - Change Log","doc":"#","ref":"changelog.html#2-2-6-2018-03-21"},{"type":"extras","title":"Fixed - Change Log","doc":"- Fixed problem with Daylight Saving Time for jobs with timezone other than UTC.\n\nDiff for [2.2.6]","ref":"changelog.html#fixed"},{"type":"extras","title":"2.2.5 - 2018-02-26 - Change Log","doc":"#","ref":"changelog.html#2-2-5-2018-02-26"},{"type":"extras","title":"Fixed - Change Log","doc":"- Omit `gen_stage` warning on `~> 0.13`\n\nDiff for [2.2.5]","ref":"changelog.html#fixed"},{"type":"extras","title":"2.2.4 - 2018-02-23 - Change Log","doc":"#","ref":"changelog.html#2-2-4-2018-02-23"},{"type":"extras","title":"Fixed - Change Log","doc":"- Relax `timex` dependency\n\nDiff for [2.2.4]","ref":"changelog.html#fixed"},{"type":"extras","title":"2.2.3 - 2018-02-13 - Change Log","doc":"#","ref":"changelog.html#2-2-3-2018-02-13"},{"type":"extras","title":"Fixed - Change Log","doc":"- Fixed compatibility with `gen_stage ~> 0.12`\n\nDiff for [2.2.3]","ref":"changelog.html#fixed"},{"type":"extras","title":"2.2.2 - 2018-02-08 - Change Log","doc":"#","ref":"changelog.html#2-2-2-2018-02-08"},{"type":"extras","title":"Added - Change Log","doc":"- Better Debugging Capabilities\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Change Log","doc":"- Relaxed version requirements for `gen_stage`\n\nDiff for [2.2.2]","ref":"changelog.html#fixed"},{"type":"extras","title":"2.2.1 - 2018-01-03 - Change Log","doc":"#","ref":"changelog.html#2-2-1-2018-01-03"},{"type":"extras","title":"Fixed - Change Log","doc":"- sometimes the task supervisor was not running in a cluster\n\nDiff for [2.2.1]","ref":"changelog.html#fixed"},{"type":"extras","title":"2.2.0 - 2017-11-07 - Change Log","doc":"Diff for [2.2.0]\n\n#","ref":"changelog.html#2-2-0-2017-11-07"},{"type":"extras","title":"Added - Change Log","doc":"- Local run strategy","ref":"changelog.html#added"},{"type":"extras","title":"2.1.3 - 2017-11-07 - Change Log","doc":"Diff for [2.1.3]\n\n#","ref":"changelog.html#2-1-3-2017-11-07"},{"type":"extras","title":"Fixed - Change Log","doc":"- Runtime Added Jobs are executed right away instead of waiting for the next job execution.\n- Fix Typo in Doc","ref":"changelog.html#fixed"},{"type":"extras","title":"2.1.2 - 2017-11-04 - Change Log","doc":"Diff for [2.1.2]\n\n#","ref":"changelog.html#2-1-2-2017-11-04"},{"type":"extras","title":"Added - Change Log","doc":"- Distillery is not mentioned in list of package managers\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Change Log","doc":"- Source is not formatted properly\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Change Log","doc":"- Removed unused Alias from `Quantum.Job`\n- Hot upgrade is not possible due to missing supervisor","ref":"changelog.html#fixed"},{"type":"extras","title":"2.1.1 - 2017-10-02 - Change Log","doc":"Diff for [2.1.1]\n\n#","ref":"changelog.html#2-1-1-2017-10-02"},{"type":"extras","title":"Fixed - Change Log","doc":"- Resolved some Dialyzer Warnings","ref":"changelog.html#fixed"},{"type":"extras","title":"2.1.0 - 2017-09-10 - Change Log","doc":"Diff for [2.1.0]\n\n#","ref":"changelog.html#2-1-0-2017-09-10"},{"type":"extras","title":"Fixed - Change Log","doc":"- Resolved some Dialyzer Warnings","ref":"changelog.html#fixed"},{"type":"extras","title":"2.1.0-beta.1 - 2017-08-20 - Change Log","doc":"Diff for [2.1.0-beta.1]\n\nThe internal handling has been refactored onto `gen_stage`.\nThere were a few Breaking Changes which should not influence a user of the library.\n\n#","ref":"changelog.html#2-1-0-beta-1-2017-08-20"},{"type":"extras","title":"Changed - Change Log","doc":"- Replaced `call` with `cast`\n  * `Scheduler.add_job`\n  * `Scheduler.deactivate_job`\n  * `Scheduler.activate_job`\n  * `Scheduler.delete_job`\n  * `Scheduler.delete_all_jobs`\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Removed - Change Log","doc":"- The overlap handling is removed from the Job struct.\n  * removed `Job.pids`\n  * removed `Job.executable?`","ref":"changelog.html#removed"},{"type":"extras","title":"2.0.4 - 2017-09-01 - Change Log","doc":"Diff for [2.0.4]\n\n#","ref":"changelog.html#2-0-4-2017-09-01"},{"type":"extras","title":"Fixed - Change Log","doc":"- Fix Race Condition with reboot in Runner state","ref":"changelog.html#fixed"},{"type":"extras","title":"2.0.3 - 2017-08-29 - Change Log","doc":"Diff for [2.0.3]\n\n#","ref":"changelog.html#2-0-3-2017-08-29"},{"type":"extras","title":"Fixed - Change Log","doc":"- `@reboot` cron expressions","ref":"changelog.html#fixed"},{"type":"extras","title":"2.0.2 - 2017-08-23 - Change Log","doc":"Diff for [2.0.2]\n\n#","ref":"changelog.html#2-0-2-2017-08-23"},{"type":"extras","title":"Fixed - Change Log","doc":"- Updated Docs.","ref":"changelog.html#fixed"},{"type":"extras","title":"2.0.1 - 2017-08-23 - Change Log","doc":"Diff for [2.0.1]\n\n- Timezone in job configuration is now normalized into a job.","ref":"changelog.html#2-0-1-2017-08-23"},{"type":"extras","title":"2.0.0 - 2017-07-20 - Change Log","doc":"Diff for [2.0.0]\n\nThe whole library has been refactored. See the [Migration Guide](https://hexdocs.pm/quantum/migrate-v2.html).","ref":"changelog.html#2-0-0-2017-07-20"},{"type":"extras","title":"2.0.0-beta.2 - 2017-07-13 - Change Log","doc":"Diff for [2.0.0-beta.2]\n\nThe whole library has been refactored. See the [Migration Guide](https://hexdocs.pm/quantum/migrate-v2.html).","ref":"changelog.html#2-0-0-beta-2-2017-07-13"},{"type":"extras","title":"2.0.0-beta.1 - 2017-06-07 - Change Log","doc":"Diff for [2.0.0-beta.1]\n\nThe whole library has been refactored. See the [Migration Guide](https://hexdocs.pm/quantum/migrate-v2.html).","ref":"changelog.html#2-0-0-beta-1-2017-06-07"},{"type":"extras","title":"1.9.2 - 2017-05-19 - Change Log","doc":"Diff for [1.9.2]","ref":"changelog.html#1-9-2-2017-05-19"},{"type":"extras","title":"1.9.1 - 2017-03-17 - Change Log","doc":"Diff for [1.9.1]","ref":"changelog.html#1-9-1-2017-03-17"},{"type":"extras","title":"1.9.0 - 2017-02-07 - Change Log","doc":"Diff for [1.9.0]\n\n#","ref":"changelog.html#1-9-0-2017-02-07"},{"type":"extras","title":"Removed - Change Log","doc":"- Three modules were removed and replaced by [crontab](https://hex.pm/packages/crontab).\n  * `Quantum.Matcher`\n  * `Quantum.Parser`\n  * `Quantum.Translator`\n\n#","ref":"changelog.html#removed"},{"type":"extras","title":"Fixed - Change Log","doc":"- The whole cron expression syntax is now supported.\n- Crons can now be configured for Umbrella applications. See the `README` for the new syntax.\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Change Log","doc":"- Cron Expressions can now be provided via the `%Crontab.CronExpression{}` struct or via the `~e[CRON EXPRESSION]` sigil.\n- Cron Expressions can now be extended. This way second granularity of the expressions can be provided.\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Deprecated - Change Log","doc":"- The configuration property `cron` is deprecated. Use the app configuration instead.","ref":"changelog.html#deprecated"},{"type":"extras","title":"1.8.1 - 2016-11-20 - Change Log","doc":"Diff for [1.8.1]\n\n#","ref":"changelog.html#1-8-1-2016-11-20"},{"type":"extras","title":"Changed - Change Log","doc":"- Clarity on the table to not use full name of day ([Coburn Berry](https://github.com/crododile))\n- Travis testing against erlang 19.1 and elixir 1.3.3 ([Julius Beckmann](https://github.com/h4cc))\n- Don't allow \"local\" timezone. Replace Timex w. Calendar ([Lau Taarnskov](https://github.com/lau))\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Change Log","doc":"- Global cannot be used directly ([Po Chen](https://github.com/princemaple))\n- Support for timezones other than utc or local not in readme ([Coburn Berry](https://github.com/crododile))\n- Timezone as string not working in config ([Daniel Roux](https://github.com/xrx))\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Removed - Change Log","doc":"- Timex references in readme ([Coburn Berry](https://github.com/crododile))\n- License badge in README","ref":"changelog.html#removed"},{"type":"extras","title":"1.8.0 - 2016-09-19 - Change Log","doc":"Diff for [1.8.0]\n\n#","ref":"changelog.html#1-8-0-2016-09-19"},{"type":"extras","title":"Changed - Change Log","doc":"- Requires Elixir >= 1.3\n- Updated C4 contribution process to RFC42\n- Updated timex dependency to 3.0 ([Svilen Gospodinov](https://github.com/svileng))\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Change Log","doc":"- Same task could be generated multiple times in a cluster ([Po Chen](https://github.com/princemaple))\n- Elixir 1.3.0 introduced unsafe var warnings ([Jamie J Quinn](https://github.com/JamieJQuinn))\n- Typo in README ([Uģis Ozols](https://github.com/ugisozols))\n- Code coverage below 100% ([Lucas Charles](https://github.com/theoretick))\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Removed - Change Log","doc":"- Unused alias ([Philip Giuliani](https://github.com/philipgiuliani))","ref":"changelog.html#removed"},{"type":"extras","title":"1.7.1 - 2016-03-24 - Change Log","doc":"Diff for [1.7.1]\n\n#","ref":"changelog.html#1-7-1-2016-03-24"},{"type":"extras","title":"Added - Change Log","doc":"- Optional per-job timezone support\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Change Log","doc":"- Nodes defaulting in `%Quantum.Job` struct\n- `job.nodes` defaulting in the normalizer\n- Test suite after changing defaulting of nodes property for the `%Quantum.Jobs{}` struct","ref":"changelog.html#fixed"},{"type":"extras","title":"1.7.0 - 2016-03-09 - Change Log","doc":"Diff for [1.7.0]\n\n#","ref":"changelog.html#1-7-0-2016-03-09"},{"type":"extras","title":"Added - Change Log","doc":"- ToC to README\n- Documentation for `overlap` option\n- Elixir 1.2 to Travis-CI config\n- Prevent duplicate job-names at runtime ([Kai Faber](https://github.com/kaiatgithub))\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Change Log","doc":"- ToC markdown\n- Default values are now configurable\n- Updated all dependencies\n- Required Elixir version is now `>= 1.2`\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Change Log","doc":"- Overlap option was not set to jobs\n- Incorrect example in README\n- Timezone is not configurable at runtime\n- Credo warnings\n- GenServer restarts when one of the jobs crashes (#82)","ref":"changelog.html#fixed"},{"type":"extras","title":"1.6.1 - 2015-12-09 - Change Log","doc":"Diff for [1.6.1]\n\n#","ref":"changelog.html#1-6-1-2015-12-09"},{"type":"extras","title":"Fixed - Change Log","doc":"- `@reboot` entries are throwing errors\n- Credo warnings and software design suggestions\n- Elixir 1.2 warnings\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Change Log","doc":"- Dependency 'credo' updated\n- Refactored range variables\n- `.gitignore` updated","ref":"changelog.html#changed"},{"type":"extras","title":"1.6.0 - 2015-11-25 - Change Log","doc":"Diff for [1.6.0]\n\n#","ref":"changelog.html#1-6-0-2015-11-25"},{"type":"extras","title":"Added - Change Log","doc":"- PID of last executed task to job struct\n- Credo code linter (only for dev and test)\n- Total downloads badge to README\n- Elixir 1.1.0 and Erlang 18.1 to Travis-CI config\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Change Log","doc":"- Max hour is 23, not 24\n- Long-running jobs could overlap\n- Typo in README ([Lucas Charles](https://github.com/theoretick))\n- Incorrect function and response types in readme ([Bart van Zon](https://github.com/bartj3))\n- Unnamed job tuples cannot take args ([Lucas Charles](https://github.com/theoretick))\n- Job names can only be atoms and can't be GC ([Luis Hurtado](https://github.com/luishurtado))","ref":"changelog.html#fixed"},{"type":"extras","title":"1.5.0 - 2015-09-24 - Change Log","doc":"Diff for [1.5.0]\n\n#","ref":"changelog.html#1-5-0-2015-09-24"},{"type":"extras","title":"Added - Change Log","doc":"- Ability to run jobs on exact node ([Rodion Vshevtsov](https://github.com/alPacino))\n- Documentation of named jobs\n- OTP 17.5 and 18.0 to Travis tests\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Change Log","doc":"- `ex_doc` dependency version\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Change Log","doc":"- Typos in README","ref":"changelog.html#fixed"},{"type":"extras","title":"1.4.0 - 2015-09-02 - Change Log","doc":"Diff for [1.4.0]\n\n#","ref":"changelog.html#1-4-0-2015-09-02"},{"type":"extras","title":"Added - Change Log","doc":"- Named jobs and the ability to (de)activate them ([Rodion Vshevtsov](https://github.com/alPacino))\n- Doc annotations for functions\n- Inch-CI integration\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Change Log","doc":"- Updated `ex_doc` dependency","ref":"changelog.html#changed"},{"type":"extras","title":"1.3.2 - 2015-08-22 - Change Log","doc":"Diff for [1.3.2]\n\n#","ref":"changelog.html#1-3-2-2015-08-22"},{"type":"extras","title":"Added - Change Log","doc":"- Timezone option to README.\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Change Log","doc":"- Using `@reboot` lead to crash.","ref":"changelog.html#fixed"},{"type":"extras","title":"1.3.1 - 2015-07-27 - Change Log","doc":"Diff for [1.3.1]\n\n#","ref":"changelog.html#1-3-1-2015-07-27"},{"type":"extras","title":"Added - Change Log","doc":"- Added contributors to changelog and project description\n- Option to use local timezone instead of UTC.\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Change Log","doc":"- Tables in README use markdown format","ref":"changelog.html#changed"},{"type":"extras","title":"1.3.0 - 2015-07-15 - Change Log","doc":"Diff for [1.3.0]\n\n\n#","ref":"changelog.html#1-3-0-2015-07-15"},{"type":"extras","title":"Added - Change Log","doc":"- Allow cron-like job formatting (`\"* * * * * MyApp.MyModule.my_method\"`) ([Rodion Vshevtsov](https://github.com/alPacino))\n- Allow defining functions as tuple (`{\"Module\", :method}`) in config ([Rodion Vshevtsov](https://github.com/alPacino))\n- Note about UTC ([Lenz Gschwendtner](https://github.com/norbu09))","ref":"changelog.html#added"},{"type":"extras","title":"1.2.4 - 2015-06-22 - Change Log","doc":"Diff for [1.2.4]\n\n#","ref":"changelog.html#1-2-4-2015-06-22"},{"type":"extras","title":"Changed - Change Log","doc":"- Renamed parse/5 functions to do_parse/5 and made them private\n- Always use `{expression, fun}` for jobs\n- Moved duplicate code to new private function `only_multiplier_of/2`\n- Moved code to normalize jobs to separate module\n- Correctly use passed state in Quantum.init/1 function\n- Moved reboot logic to executor.\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Removed - Change Log","doc":"- Unnecessary guard clause\n- Unused parse/3 functions\n- Unused call to String.split on patterns starting with \"*/\"","ref":"changelog.html#removed"},{"type":"extras","title":"1.2.3 - 2015-06-15 - Change Log","doc":"Diff for [1.2.3]\n\n#","ref":"changelog.html#1-2-3-2015-06-15"},{"type":"extras","title":"Added - Change Log","doc":"- Support for `@reboot`\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Change Log","doc":"- Does not convert jobs defined in config","ref":"changelog.html#fixed"},{"type":"extras","title":"1.2.2 - 2015-06-15 - Change Log","doc":"Diff for [1.2.2]\n\n#","ref":"changelog.html#1-2-2-2015-06-15"},{"type":"extras","title":"Added - Change Log","doc":"- Support for `@annually` and `@midnight`\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Change Log","doc":"- Function order in Quantum.Matcher\n- Renamed private translate function to do_translate\n- Do not convert and translate cron expressions on every tick\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Change Log","doc":"- Adding a job using Quantum.add_job/2 does not convert to lowercase\n- Adding a job using Quantum.add_job/2 does not translate day/month names","ref":"changelog.html#fixed"},{"type":"extras","title":"1.2.1 - 2015-06-13 - Change Log","doc":"Diff for [1.2.1]\n\n#","ref":"changelog.html#1-2-1-2015-06-13"},{"type":"extras","title":"Added - Change Log","doc":"- Test for handle_info(:tick_state)\n- Dependencies to generate hexdocs\n- Badge for hexdocs\n- Link to docs in hex package info\n- Type specs and doc annotations\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Change Log","doc":"- Quantum.Application does not call Quantum.start_link/1 anymore\n- Moved match logic to separate module Quantum.Matcher\n- Moved parsing logic to separate module Quantum.Parser\n- Moved execution logic to separate module Quantum.Executor\n- Moved translation logic to separate module Quantum.Translator\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Change Log","doc":"- Typos in changelog\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Removed - Change Log","doc":"- Quantum.start_link/1","ref":"changelog.html#removed"},{"type":"extras","title":"1.2.0 - 2015-06-11 - Change Log","doc":"Diff for [1.2.0]\n\n#","ref":"changelog.html#1-2-0-2015-06-11"},{"type":"extras","title":"Changed - Change Log","doc":"- Date is updated in state only if it changed\n- Wake up every minute instead of every second\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Change Log","doc":"- Intervals on ranges are not correctly parsed\n- Hour constraints are not correct ([Lenz Gschwendtner](https://github.com/norbu09))\n- There is no changelog\n- Code coverage is low\n- Explicit variables are not needed\n- Pattern matching can be simplified","ref":"changelog.html#fixed"},{"type":"extras","title":"1.1.0 - 2015-05-28 - Change Log","doc":"Diff for [1.1.0]\n\n#","ref":"changelog.html#1-1-0-2015-05-28"},{"type":"extras","title":"Added - Change Log","doc":"- Add ability to schedule jobs at runtime and ability to view jobs ([Dan Swain](https://github.com/dantswain))\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Change Log","doc":"- Relax Elixir version","ref":"changelog.html#changed"},{"type":"extras","title":"1.0.4 - 2015-05-26 - Change Log","doc":"Diff for [1.0.4]\n\n#","ref":"changelog.html#1-0-4-2015-05-26"},{"type":"extras","title":"Fixed - Change Log","doc":"- Written month and weekday names are not parsed","ref":"changelog.html#fixed"},{"type":"extras","title":"1.0.3 - 2015-05-01 - Change Log","doc":"Diff for [1.0.3]\n\n#","ref":"changelog.html#1-0-3-2015-05-01"},{"type":"extras","title":"Fixed - Change Log","doc":"- Do not fire on first tick","ref":"changelog.html#fixed"},{"type":"extras","title":"1.0.2 - 2015-04-29 - Change Log","doc":"Diff for [1.0.2]\n\n#","ref":"changelog.html#1-0-2-2015-04-29"},{"type":"extras","title":"Fixed - Change Log","doc":"- Special expressions are not correctly in all cases\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Removed - Change Log","doc":"- Functions to add and reset jobs","ref":"changelog.html#removed"},{"type":"extras","title":"1.0.1 - 2015-04-27 - Change Log","doc":"Diff for [1.0.1]\n\n#","ref":"changelog.html#1-0-1-2015-04-27"},{"type":"extras","title":"Added - Change Log","doc":"- Configure cronjobs in config\n- Add application\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Change Log","doc":"- Parsing of cron expression fails","ref":"changelog.html#fixed"},{"type":"extras","title":"1.0.0 - 2015-04-27 - Change Log","doc":"Diff for [1.0.0]\n\n#","ref":"changelog.html#1-0-0-2015-04-27"},{"type":"extras","title":"Added - Change Log","doc":"- Initial commit\n\n[unreleased]: https://github.com/quantum-elixir/quantum-core/compare/v3.4.0...HEAD\n[3.4.0]: https://github.com/quantum-elixir/quantum-core/compare/v3.3.0...v3.4.0\n[3.3.0]: https://github.com/quantum-elixir/quantum-core/compare/v3.2.0...v3.3.0\n[3.2.0]: https://github.com/quantum-elixir/quantum-core/compare/v3.1.0...v3.2.0\n[3.1.0]: https://github.com/quantum-elixir/quantum-core/compare/v3.0.2...v3.1.0\n[3.0.2]: https://github.com/quantum-elixir/quantum-core/compare/v3.0.1...v3.0.2\n[3.0.1]: https://github.com/quantum-elixir/quantum-core/compare/v3.0.0...v3.0.1\n[3.0.0]: https://github.com/quantum-elixir/quantum-core/compare/v3.0.0-rc.3...v3.0.0\n[3.0.0-rc.3]: https://github.com/quantum-elixir/quantum-core/compare/v3.0.0-rc.2...v3.0.0-rc.3\n[3.0.0-rc.2]: https://github.com/quantum-elixir/quantum-core/compare/v3.0.0-rc.1...v3.0.0-rc.2\n[3.0.0-rc.1]: https://github.com/quantum-elixir/quantum-core/compare/v2.4.0...v3.0.0-rc.1\n[2.4.0]: https://github.com/quantum-elixir/quantum-core/compare/v2.3.4...v2.4.0\n[2.3.4]: https://github.com/quantum-elixir/quantum-core/compare/v2.3.3...v2.3.4\n[2.3.3]: https://github.com/quantum-elixir/quantum-core/compare/v2.3.2...v2.3.3\n[2.3.2]: https://github.com/quantum-elixir/quantum-core/compare/v2.3.1...v2.3.2\n[2.3.1]: https://github.com/quantum-elixir/quantum-core/compare/v2.3.0...v2.3.1\n[2.3.0]: https://github.com/quantum-elixir/quantum-core/compare/v2.2.7...v2.3.0\n[2.2.7]: https://github.com/quantum-elixir/quantum-core/compare/v2.2.6...v2.2.7\n[2.2.6]: https://github.com/quantum-elixir/quantum-core/compare/v2.2.5...v2.2.6\n[2.2.5]: https://github.com/quantum-elixir/quantum-core/compare/v2.2.4...v2.2.5\n[2.2.4]: https://github.com/quantum-elixir/quantum-core/compare/v2.2.3...v2.2.4\n[2.2.3]: https://github.com/quantum-elixir/quantum-core/compare/v2.2.2...v2.2.3\n[2.2.2]: https://github.com/quantum-elixir/quantum-core/compare/v2.2.1...v2.2.2\n[2.2.1]: https://github.com/quantum-elixir/quantum-core/compare/v2.2.0...v2.2.1\n[2.2.0]: https://github.com/quantum-elixir/quantum-core/compare/v2.1.3...v2.2.0\n[2.1.3]: https://github.com/quantum-elixir/quantum-core/compare/v2.1.2...v2.1.3\n[2.1.2]: https://github.com/quantum-elixir/quantum-core/compare/v2.1.1...v2.1.2\n[2.1.1]: https://github.com/quantum-elixir/quantum-core/compare/v2.1.0...v2.1.1\n[2.1.0]: https://github.com/quantum-elixir/quantum-core/compare/v2.1.0-beta.1...v2.1.0\n[2.1.0-beta.1]: https://github.com/quantum-elixir/quantum-core/compare/v2.0.4...v2.1.0-beta.1\n[2.0.4]: https://github.com/quantum-elixir/quantum-core/compare/v2.0.3...v2.0.4\n[2.0.3]: https://github.com/quantum-elixir/quantum-core/compare/v2.0.2...v2.0.3\n[2.0.2]: https://github.com/quantum-elixir/quantum-core/compare/v2.0.1...v2.0.2\n[2.0.1]: https://github.com/quantum-elixir/quantum-core/compare/v2.0.0...v2.0.1\n[2.0.0]: https://github.com/quantum-elixir/quantum-core/compare/v2.0.0-beta.2...v2.0.0\n[2.0.0-beta.2]: https://github.com/quantum-elixir/quantum-core/compare/v2.0.0-beta.1...v2.0.0-beta.2\n[2.0.0-beta.1]: https://github.com/quantum-elixir/quantum-core/compare/v1.9.2...v2.0.0-beta.1\n[1.9.2]: https://github.com/quantum-elixir/quantum-core/compare/v1.9.1...v1.9.2\n[1.9.1]: https://github.com/quantum-elixir/quantum-core/compare/v1.9.0...v1.9.1\n[1.9.0]: https://github.com/quantum-elixir/quantum-core/compare/v1.8.1...v1.9.0\n[1.8.1]: https://github.com/quantum-elixir/quantum-core/compare/v1.8.0...v1.8.1\n[1.8.0]: https://github.com/quantum-elixir/quantum-core/compare/v1.7.1...v1.8.0\n[1.7.1]: https://github.com/quantum-elixir/quantum-core/compare/v1.7.0...v1.7.1\n[1.7.0]: https://github.com/quantum-elixir/quantum-core/compare/v1.6.1...v1.7.0\n[1.6.1]: https://github.com/quantum-elixir/quantum-core/compare/v1.6.0...v1.6.1\n[1.6.0]: https://github.com/quantum-elixir/quantum-core/compare/v1.5.0...v1.6.0\n[1.5.0]: https://github.com/quantum-elixir/quantum-core/compare/v1.4.0...v1.5.0\n[1.4.0]: https://github.com/quantum-elixir/quantum-core/compare/v1.3.2...v1.4.0\n[1.3.2]: https://github.com/quantum-elixir/quantum-core/compare/v1.3.1...v1.3.2\n[1.3.1]: https://github.com/quantum-elixir/quantum-core/compare/v1.3.0...v1.3.1\n[1.3.0]: https://github.com/quantum-elixir/quantum-core/compare/v1.2.4...v1.3.0\n[1.2.4]: https://github.com/quantum-elixir/quantum-core/compare/v1.2.3...v1.2.4\n[1.2.3]: https://github.com/quantum-elixir/quantum-core/compare/v1.2.2...v1.2.3\n[1.2.2]: https://github.com/quantum-elixir/quantum-core/compare/v1.2.1...v1.2.2\n[1.2.1]: https://github.com/quantum-elixir/quantum-core/compare/v1.2.0...v1.2.1\n[1.2.0]: https://github.com/quantum-elixir/quantum-core/compare/v1.1.0...v1.2.0\n[1.1.0]: https://github.com/quantum-elixir/quantum-core/compare/v1.0.4...v1.1.0\n[1.0.4]: https://github.com/quantum-elixir/quantum-core/compare/v1.0.3...v1.0.4\n[1.0.3]: https://github.com/quantum-elixir/quantum-core/compare/v1.0.2...v1.0.3\n[1.0.2]: https://github.com/quantum-elixir/quantum-core/compare/v1.0.1...v1.0.2\n[1.0.1]: https://github.com/quantum-elixir/quantum-core/compare/v1.0.0...v1.0.1\n[1.0.0]: https://github.com/quantum-elixir/quantum-core/commit/9a58b5f5c02a2de6cde4c579c9f879f1fb49b305","ref":"changelog.html#added"},{"type":"extras","title":"Quantum","doc":"# Quantum\n\n[![Financial Contributors on Open Collective](https://opencollective.com/quantum/all/badge.svg?label=financial+contributors)](https://opencollective.com/quantum)\n[![.github/workflows/branch_main.yml](https://github.com/quantum-elixir/quantum-core/actions/workflows/branch_main.yml/badge.svg)](https://github.com/quantum-elixir/quantum-core/actions/workflows/branch_main.yml)\n[![Coverage Status](https://coveralls.io/repos/quantum-elixir/quantum-core/badge.svg?branch=main)](https://coveralls.io/r/quantum-elixir/quantum-core?branch=main)\n[![Module Version](https://img.shields.io/hexpm/v/quantum.svg)](https://hex.pm/packages/quantum)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/quantum/)\n[![Total Download](https://img.shields.io/hexpm/dt/quantum.svg)](https://hex.pm/packages/quantum)\n[![License](https://img.shields.io/hexpm/l/quantum.svg)](https://github.com/quantum-elixir/quantum-core/blob/main/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/quantum-elixir/quantum-core.svg)](https://github.com/quantum-elixir/quantum-core/commits/main)\n\n> **This README follows main, which may not be the currently published version**. Here are the\n[docs for the latest published version of Quantum](https://hexdocs.pm/quantum/readme.html).\n\n[Cron](https://en.wikipedia.org/wiki/Cron)-like job scheduler for [Elixir](http://elixir-lang.org/).","ref":"readme.html"},{"type":"extras","title":"Setup - Quantum","doc":"To use Quantum in your project, edit the `mix.exs` file and add `Quantum` to\n\n**1. the list of dependencies:**\n```elixir\ndefp deps do\n  [\n    {:quantum, \"~> 3.0\"}\n  ]\nend\n```\n\n**2. and create a scheduler for your app:**\n```elixir\ndefmodule Acme.Scheduler do\n  use Quantum, otp_app: :your_app\nend\n```\n\n**3. and your application's supervision tree:**\n```elixir\ndefmodule Acme.Application do\n  use Application\n\n  def start(_type, _args) do\n    children = [\n      # This is the new line\n      Acme.Scheduler\n    ]\n\n    opts = [strategy: :one_for_one, name: Acme.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```","ref":"readme.html#setup"},{"type":"extras","title":"Troubleshooting - Quantum","doc":"To see more transparently what `quantum` is doing, configure the `logger` to display `:debug` messages.\n\n```elixir\nconfig :logger, level: :debug\n```\n\nIf you want do use the logger in debug-level without the messages from quantum:\n\n```elixir\nconfig :acme, Acme.Scheduler,\n  debug_logging: false\n```\n\nIf you encounter any problems with `quantum`, please search if there is already an\n  [open issue](https://github.com/quantum-elixir/quantum-core/issues) addressing the problem.\n\nOtherwise feel free to [open an issue](https://github.com/quantum-elixir/quantum-core/issues/new). Please include debug logs.","ref":"readme.html#troubleshooting"},{"type":"extras","title":"Usage - Quantum","doc":"Configure your cronjobs in your `config/config.exs` like this:\n\n```elixir\nconfig :acme, Acme.Scheduler,\n  jobs: [\n    # Every minute\n    {\"* * * * *\",      {Heartbeat, :send, []}},\n    # Every 15 minutes\n    {\"*/15 * * * *\",   fn -> System.cmd(\"rm\", [\"/tmp/tmp_\"]) end},\n    # Runs on 18, 20, 22, 0, 2, 4, 6:\n    {\"0 18-6/2 * * *\", fn -> :mnesia.backup('/var/backup/mnesia') end},\n    # Runs every midnight:\n    {\"@daily\",         {Backup, :backup, []}}\n  ]\n```\n\nMore details on the usage can be found in the [Documentation](https://hexdocs.pm/quantum/configuration.html)","ref":"readme.html#usage"},{"type":"extras","title":"Contribution - Quantum","doc":"This project uses the [Collective Code Construction Contract (C4)](http://rfc.zeromq.org/spec:42/C4/) for all code changes.\n\n> \"Everyone, without distinction or discrimination, SHALL have an equal right to become a Contributor under the terms of this contract.\"\n\n#","ref":"readme.html#contribution"},{"type":"extras","title":"TL;DR - Quantum","doc":"1. Check for [open issues](https://github.com/quantum-elixir/quantum-core/issues) or [open a new issue](https://github.com/quantum-elixir/quantum-core/issues/new) to start a discussion around [a problem](https://www.youtube.com/watch?v=_QF9sFJGJuc).\n2. Issues SHALL be named as \"Problem: _description of the problem_\".\n3. Fork the [quantum-elixir repository on GitHub](https://github.com/quantum-elixir/quantum-core) to start making your changes\n4. If possible, write a test which shows that the problem was solved.\n5. Send a pull request.\n6. Pull requests SHALL be named as \"Solution: _description of your solution_\"\n7. Your pull request is merged and you are added to the [list of contributors](https://github.com/quantum-elixir/quantum-core/graphs/contributors)\n\n#","ref":"readme.html#tl-dr"},{"type":"extras","title":"Code Contributors - Quantum","doc":"This project exists thanks to all the people who contribute.\n\n[![Contributors](https://opencollective.com/quantum/contributors.svg?width=890&button=false)](https://github.com/quantum-elixir/quantum-core/graphs/contributors)\n\n#","ref":"readme.html#code-contributors"},{"type":"extras","title":"Financial Contributors - Quantum","doc":"Become a financial contributor and help us sustain our community. [[Contribute](https://opencollective.com/quantum/contribute)]\n\n##","ref":"readme.html#financial-contributors"},{"type":"extras","title":"Individuals - Quantum","doc":"[![Individuals](https://opencollective.com/quantum/individuals.svg?width=890)](https://opencollective.com/quantum)\n\n##","ref":"readme.html#individuals"},{"type":"extras","title":"Organizations - Quantum","doc":"Support this project with your organization. Your logo will show up here with a link to your website. [[Contribute](https://opencollective.com/quantum/contribute)]\n\n[![Organization0](https://opencollective.com/quantum/organization/0/avatar.svg)](https://opencollective.com/quantum/organization/0/website)\n[![Organization1](https://opencollective.com/quantum/organization/1/avatar.svg)](https://opencollective.com/quantum/organization/1/website)\n[![Organization2](https://opencollective.com/quantum/organization/2/avatar.svg)](https://opencollective.com/quantum/organization/2/website)\n[![Organization3](https://opencollective.com/quantum/organization/3/avatar.svg)](https://opencollective.com/quantum/organization/3/website)\n[![Organization4](https://opencollective.com/quantum/organization/4/avatar.svg)](https://opencollective.com/quantum/organization/4/website)\n[![Organization5](https://opencollective.com/quantum/organization/5/avatar.svg)](https://opencollective.com/quantum/organization/5/website)\n[![Organization6](https://opencollective.com/quantum/organization/6/avatar.svg)](https://opencollective.com/quantum/organization/6/website)\n[![Organization7](https://opencollective.com/quantum/organization/7/avatar.svg)](https://opencollective.com/quantum/organization/7/website)\n[![Organization8](https://opencollective.com/quantum/organization/8/avatar.svg)](https://opencollective.com/quantum/organization/8/website)\n[![Organization9](https://opencollective.com/quantum/organization/9/avatar.svg)](https://opencollective.com/quantum/organization/9/website)","ref":"readme.html#organizations"},{"type":"extras","title":"Copyright and License - Quantum","doc":"Copyright (c) 2015 Constantin Rack\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"Supervision Tree","doc":"# Supervision Tree\n\n* `YourApp.Scheduler` (`Quantum`) - Your primary Interface to interact with. (Like `add_job/1` etc.)\n  - `YourApp.Scheduler.Supervisor` (`Quantum.Supervisor`) - The Supervisor that coordinates configuration, the runner and task supervisor.\n    * `YourApp.Scheduler.TaskRegistry` (`Quantum.TaskRegistry`) - The `GenServer` that keeps track of running tasks and prevents overlap.\n    * `YourApp.Scheduler.JobBroadcaster` (`Quantum.JobBroadcaster`) - The `GenStage` that keeps track of all jobs.\n    * `YourApp.Scheduler.ExecutionBroadcaster` (`Quantum.ExecutionBroadcaster`) - The `GenStage` that notifies execution of jobs.\n    * `YourApp.Scheduler.ExecutorSupervisor` (`Quantum.ExecutorSupervisor`) - The `ConsumerSupervisor` that spawns an Executor for every execution.\n      - `no_name` (`YourApp.Scheduler.Executor`) - The `Task` that calls the `YourApp.Scheduler.TaskSupervisor` with the execution of the Cron (per Node).\n    * `YourApp.Scheduler.TaskSupervisor` (`Task.Supervisor`) - The `Task.Supervisor` where all Cron jobs run in.\n      - `Task` - The place where the defined Cron job action gets called.","ref":"supervision-tree.html"},{"type":"extras","title":"Error Handling - Supervision Tree","doc":"The OTP Supervision Tree is initiated by the user of the library. Therefore the error handling can be implemented via normal OTP means. See `Supervisor` module for more information.","ref":"supervision-tree.html#error-handling"},{"type":"extras","title":"Configuration","doc":"# Configuration\n\nConfigure your cronjobs in your `config/config.exs` like this:\n\n```elixir\nconfig :your_app, YourApp.Scheduler,\n  jobs: [\n    # Every minute\n    {\"* * * * *\",              {Heartbeat, :send, []}},\n    {{:cron, \"* * * * *\"},     {Heartbeat, :send, []}},\n    # Every second\n    {{:extended, \"* * * * *\"}, {Heartbeat, :send, []}},\n    # Every 15 minutes\n    {\"*/15 * * * *\",           fn -> System.cmd(\"rm\", [\"/tmp/tmp_\"]) end},\n    # Runs on 18, 20, 22, 0, 2, 4, 6:\n    {\"0 18-6/2 * * *\",         fn -> :mnesia.backup('/var/backup/mnesia') end},\n    # Runs every midnight:\n    {\"@daily\",                 {Backup, :backup, []}, state: :inactive}\n  ]\n```","ref":"configuration.html"},{"type":"extras","title":"Persistent Storage - Configuration","doc":"Persistent storage can be used to track jobs and last execution times over restarts.\n\n**Note: If a storage is present, the jobs from the configuration will not be loaded to prevent conflicts.**\n\n```elixir\nconfig :your_app, YourApp.Scheduler,\n  storage: Quantum.Storage.Implementation\n```\n\n#","ref":"configuration.html#persistent-storage"},{"type":"extras","title":"Storage Adapters - Configuration","doc":"Storage implementations must implement the `Quantum.Storage` behaviour.\n\nThe following adapters are supported:\n\n* [`PersistentEts`](https://hex.pm/packages/quantum_storage_persistent_ets)\n* [`Mnesia`](https://hex.pm/packages/quantum_storage_mnesia)","ref":"configuration.html#storage-adapters"},{"type":"extras","title":"Release managers - Configuration","doc":"(\n[conform](https://github.com/bitwalker/conform) /\n[distillery](https://github.com/bitwalker/distillery) /\n[exrm](https://github.com/bitwalker/exrm) /\n[edeliver](https://github.com/boldpoker/edeliver)\n)\n\nPlease note that the following config notation **is not supported** by release managers.\n\n```elixir\n{\"* * * * *\", fn -> :anonymous_function end}\n```","ref":"configuration.html#release-managers"},{"type":"extras","title":"Named Jobs - Configuration","doc":"You can define named jobs in your config like this:\n\n```elixir\nconfig :your_app, YourApp.Scheduler,\n  jobs: [\n    news_letter: [\n      schedule: \"@weekly\",\n      task: {Heartbeat, :send, [:arg1]},\n    ]\n  ]\n```\n\nPossible options:\n- `schedule` cron schedule, ex: `\"@weekly\"` / `\"1 * * * *\"` / `{:cron, \"1 * * * *\"}` or `{:extended, \"1 * * * *\"}`\n- `task` function to be performed, ex: `{Heartbeat, :send, []}` or `fn -> :something end`\n- `run_strategy` strategy on how to run tasks inside of cluster, default: `%Quantum.RunStrategy.Random{nodes: :cluster}`\n- `overlap` set to false to prevent next job from being executed if previous job is still running, default: `true`\n- `state` set to `:inactive` to deactivate a job or `:active` to activate it\n\nIt is possible to control the behavior of jobs at runtime.","ref":"configuration.html#named-jobs"},{"type":"extras","title":"Override default settings - Configuration","doc":"The default job settings can be configured as shown in the example below.\nSo if you have a lot of jobs and do not want to override the\ndefault setting in every job, you can set them globally.\n\n```elixir\nconfig :your_app, YourApp.Scheduler,\n  schedule: \"* * * * *\",\n  overlap: false,\n  timezone: :utc,\n  jobs: [\n    # Your cronjobs\n  ]\n```","ref":"configuration.html#override-default-settings"},{"type":"extras","title":"Jobs with Second granularity - Configuration","doc":"It is possible to specify jobs with second granularity.\nTo do this the `schedule` parameter has to be provided with a `{:extended, \"1 * * * *\"}` expression.\n\n```elixir\nconfig :your_app, YourApp.Scheduler,\n  jobs: [\n    news_letter: [\n      schedule: {:extended, \"*/2\"}, # Runs every two seconds\n      task: {Heartbeat, :send, [:arg1]}\n    ]\n  ]\n```","ref":"configuration.html#jobs-with-second-granularity"},{"type":"extras","title":"GenServer timeout - Configuration","doc":"Sometimes, you may come across GenServer timeout errors esp. when you have\ntoo many jobs or high load. The default `GenServer.call` timeout is 5000.\nYou can override this default by specifying `timeout` setting in configuration.\n\n```elixir\nconfig :your_app, YourApp.Scheduler,\n  timeout: 30_000\n```\n\nOr if you wish to wait indefinitely:\n\n```elixir\nconfig :your_app, YourApp.Scheduler,\n  timeout: :infinity\n```","ref":"configuration.html#genserver-timeout"},{"type":"extras","title":"Timezone Support - Configuration","doc":"Please note that Quantum uses **UTC timezone** and not local timezone.\n\nBefore changing the timezone you need to install [Tzdata](https://github.com/lau/tzdata) and add the following line in your config file.\n\n```elixir\nconfig :elixir, :time_zone_database, Tzdata.TimeZoneDatabase\n```\n\nNow you can specify another default timezone, add the following `timezone` option to your configuration:\n\n```elixir\nconfig :your_app, YourApp.Scheduler,\n  timezone: \"America/Chicago\",\n  jobs: [\n    # Your cronjobs\n  ]\n```\n\nValid options are `:utc` or a timezone name such as `\"America/Chicago\"`. A full list of timezone names can be downloaded from https://www.iana.org/time-zones, or at https://en.wikipedia.org/wiki/List_of_tz_database_time_zones.\n\nTimezones can also be configured on a per-job basis. This overrides the default Quantum timezone for a particular job. To set the timezone on a job, use the `timezone` key when creating the `Quantum.Job` structure.\n\n```elixir\n%Quantum.Job{\n  # ...\n  timezone: \"America/New_York\"\n}\n```","ref":"configuration.html#timezone-support"},{"type":"extras","title":"Runtime Configuration","doc":"# Runtime Configuration\n\nIf you want to add jobs on runtime, this is possible too:\n\n```elixir\nimport Crontab.CronExpression\n\nYourApp.Scheduler.add_job({~e[1 * * * *], fn -> :ok end})\n```\n\nAdd a named job at runtime:\n\n```elixir\nimport Crontab.CronExpression\n\nYourApp.Scheduler.new_job()\n|> Quantum.Job.set_name(:ticker)\n|> Quantum.Job.set_schedule(~e[1 * * * *])\n|> Quantum.Job.set_task(fn -> :ok end)\n|> YourApp.Scheduler.add_job()\n```\n\nDeactivate a job, i.e. it will not be performed until job is activated again:\n```elixir\nYourApp.Scheduler.deactivate_job(:ticker)\n```\n\nActivate an inactive job:\n```elixir\nYourApp.Scheduler.activate_job(:ticker)\n```\n\nRun a job once outside of normal schedule:\n```elixir\nYourApp.Scheduler.run_job(:ticker)\n```\n\nFind a job:\n```elixir\nYourApp.Scheduler.find_job(:ticker)\n# %Quantum.Job{...}\n```\n\nDelete a job:\n```elixir\nYourApp.Scheduler.delete_job(:ticker)\n# %Quantum.Job{...}\n```","ref":"runtime-configuration.html"},{"type":"extras","title":"Jobs with Second granularity - Runtime Configuration","doc":"It is possible to specify jobs with second granularity.\nTo do this the `schedule` parameter has to be provided with either a `%Crontab.CronExpression{extended: true, ...}` or\nwith a set `e` flag on the `e` sigil. (The sigil must be imported from `Crontab.CronExpression`)\n\nThe following example will put a tick into the `stdout` every first second of every minute.\n\n```elixir\nimport Crontab.CronExpression\n\nYourApp.Scheduler.new_job()\n|> Quantum.Job.set_name(:ticker)\n|> Quantum.Job.set_schedule(~e[1 * * * *]e)\n|> Quantum.Job.set_task(fn -> IO.puts \"tick\" end)\n|> YourApp.Scheduler.add_job()\n```","ref":"runtime-configuration.html#jobs-with-second-granularity"},{"type":"extras","title":"Crontab format","doc":"# Crontab format","ref":"crontab-format.html"},{"type":"extras","title":"Basics - Crontab format","doc":"| Field        | Allowed values                              |\n| ------------ | ------------------------------------------- |\n| second       | 0-59                                        |\n| minute       | 0-59                                        |\n| hour         | 0-23                                        |\n| day of month | 1-31                                        |\n| month        | 1-12 (or names)                             |\n| day of week  | 0-6 (0 is Sunday, or use abbreviated names) |\n\nThe `second` field can only be used in extended Cron expressions.\n\nNames can also be used for the `month` and `day of week` fields.\nUse the first three letters of the particular day or month (case does not matter).","ref":"crontab-format.html#basics"},{"type":"extras","title":"Special expressions - Crontab format","doc":"Instead of the first five fields, one of these special strings may be used:\n\n| String      | Description                                               |\n| ----------- | --------------------------------------------------------- |\n| `@annually` | Run once a year, same as `~e[\"0 0 1 1 *\"]` or `@yearly`   |\n| `@daily`    | Run once a day, same as `~e[\"0 0 * * *\"]` or `@midnight`  |\n| `@hourly`   | Run once an hour, same as `~e[\"0 * * * *\"]`               |\n| `@midnight` | Run once a day, same as `~e[\"0 0 * * *\"]` or `@daily`     |\n| `@minutely` | Run once a minute, same as `~e[\"* * * * *\"]`              |\n| `@monthly`  | Run once a month, same as `~e[\"0 0 1 * *\"]`               |\n| `@reboot`   | Run once, at startup                                      |\n| `@secondly` | Run once a second, same as `~e[\"* * * * * *\"]e`           |\n| `@weekly`   | Run once a week, same as `~e[\"0 0 * * 0\"]`                |\n| `@yearly`   | Run once a year, same as `~e[\"0 0 1 1 *\"]` or `@annually` |","ref":"crontab-format.html#special-expressions"},{"type":"extras","title":"Supported Notations - Crontab format","doc":"* [Oracle](https://docs.oracle.com/cd/E12058_01/doc/doc.1014/e12030/cron_expressions.htm)\n* [Cron Format](http://www.nncron.ru/help/EN/working/cron-format.htm)\n* [Wikipedia](https://en.wikipedia.org/wiki/Cron)","ref":"crontab-format.html#supported-notations"},{"type":"extras","title":"Crontab Dependency - Crontab format","doc":"All Cron Expressions are parsed and evaluated by [crontab](https://hex.pm/packages/crontab).\n\nIssues with parsing a Cron expression can be reported here:\n[crontab GitHub issues](https://github.com/jshmrtn/crontab/issues)","ref":"crontab-format.html#crontab-dependency"},{"type":"extras","title":"Run Strategies","doc":"# Run Strategies\n\nTasks can be executed via different run strategies.","ref":"run-strategies.html"},{"type":"extras","title":"Configuration - Run Strategies","doc":"#","ref":"run-strategies.html#configuration"},{"type":"extras","title":"Mix - Run Strategies","doc":"```elixir\nconfig :my_app, MyApp.Scheduler,\n  jobs: [\n    [schedule: \"* * * * *\", run_strategy: {StrategyName, options}],\n  ]\n```\n\nThe run strategy can be configured by providing a tuple of the strategy module name and it's options. If you choose `Local Node` strategy, the config should be:\n\n```elixir\nconfig :my_app, MyApp.Scheduler,\n  jobs: [\n    [schedule: \"* * * * *\", run_strategy: Quantum.RunStrategy.Local],\n  ]\n```\n\n#","ref":"run-strategies.html#mix"},{"type":"extras","title":"Runtime - Run Strategies","doc":"Provide a value that implements the `Quantum.RunStrategy.NodeList` protocol. The value will not be normalized.","ref":"run-strategies.html#runtime"},{"type":"extras","title":"Provided Strategies - Run Strategies","doc":"#","ref":"run-strategies.html#provided-strategies"},{"type":"extras","title":"All Nodes - Run Strategies","doc":"`Quantum.RunStrategy.All`\n\nIf you want to run a task on all nodes of either a list or in the whole cluster, use this strategy.\n\n#","ref":"run-strategies.html#all-nodes"},{"type":"extras","title":"Random Node - Run Strategies","doc":"`Quantum.RunStrategy.Random`\n\nIf you want to run a task on any node of either a list or in the whole cluster, use this strategy.\n\n#","ref":"run-strategies.html#random-node"},{"type":"extras","title":"Local Node - Run Strategies","doc":"`Quantum.RunStrategy.Local`\n\nIf you want to run a task on local node, use this strategy.","ref":"run-strategies.html#local-node"},{"type":"extras","title":"Custom Run Strategy - Run Strategies","doc":"Custom run strategies, can be implemented by implementing the `Quantum.RunStrategy` behaviour and the `Quantum.RunStrategy.NodeList` protocol.","ref":"run-strategies.html#custom-run-strategy"}],"content_type":"text/markdown"}